@@ -3,7 +3,7 @@
 /*
  *  File-Roller
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #ifndef PREFERENCES_H
 #define PREFERENCES_H
 
+#include <gtk/gtkwindow.h>
 #include <gtk/gtkenums.h>
 #include "typedefs.h"
 #include "window.h"
@@ -30,7 +31,6 @@
 #define PREF_LIST_SORT_METHOD      "/apps/file-roller/listing/sort_method"
 #define PREF_LIST_SORT_TYPE        "/apps/file-roller/listing/sort_type"
 #define PREF_LIST_MODE             "/apps/file-roller/listing/list_mode"
-#define PREF_LIST_SHOW_NAME        "/apps/file-roller/listing/show_name"
 #define PREF_LIST_SHOW_TYPE        "/apps/file-roller/listing/show_type"
 #define PREF_LIST_SHOW_SIZE        "/apps/file-roller/listing/show_size"
 #define PREF_LIST_SHOW_TIME        "/apps/file-roller/listing/show_time"
@@ -42,13 +42,21 @@
 #define PREF_UI_STATUSBAR          "/apps/file-roller/ui/view_statusbar"
 
 #define PREF_EDIT_EDITORS          "/apps/file-roller/general/editors"
-#define PREF_EXTRACT_VIEW_FOLDER   "/apps/file-roller/general/view_folder_after_extraction"
 #define PREF_ADD_COMPRESSION_LEVEL "/apps/file-roller/general/compression_level"
 #define PREF_MIGRATE_DIRECTORIES   "/apps/file-roller/general/migrate_directories"
 
+#define PREF_EXTRACT_VIEW_FOLDER      "/apps/file-roller/dialogs/extract/view_destination_folder"
+#define PREF_EXTRACT_OVERWRITE        "/apps/file-roller/dialogs/extract/overwrite"
+#define PREF_EXTRACT_SKIP_NEWER       "/apps/file-roller/dialogs/extract/skip_newer"
+#define PREF_EXTRACT_RECREATE_FOLDERS "/apps/file-roller/dialogs/extract/recreate_folders"
+
+#define PREF_BATCH_ADD_DEFAULT_EXTENSION "/apps/file-roller/dialogs/batch-add/default_extension"
+
 #define PREF_DESKTOP_ICON_THEME         "/desktop/gnome/file_views/icon_theme"
 #define PREF_DESKTOP_MENUS_HAVE_TEAROFF "/desktop/gnome/interface/menus_have_tearoff"
+#define PREF_DESKTOP_MENUBAR_DETACHABLE "/desktop/gnome/interface/menubar_detachable"
 #define PREF_DESKTOP_TOOLBAR_DETACHABLE "/desktop/gnome/interface/toolbar_detachable"
+#define PREF_NAUTILUS_CLICK_POLICY "/apps/nautilus/preferences/click_policy"
 
 
 WindowSortMethod    preferences_get_sort_method ();
@@ -67,5 +75,10 @@ FRCompression       preferences_get_compression_level ();
 
 void                preferences_set_compression_level (FRCompression i_value);
 
+void                pref_util_save_window_geometry (GtkWindow  *window,
+						    const char *dialog);
+
+void                pref_util_restore_window_geometry (GtkWindow  *window,
+						       const char *dialog);
 
 #endif /* PREFERENCES_H */
